#ifndef UTILS_H
#define UTILS_H

#include <unordered_map>
#include <stdexcept>

namespace Utils {

template <typename Enum>
struct EnumDictionary {
  std::unordered_map<std::string, Enum> map_to_enum;

  EnumDictionary(std::initializer_list<std::pair<std::string, Enum>> init_list) {
    for (const auto& pair : init_list) {
      map_to_enum.insert(pair);
    }
  }

  Enum operator()(std::string str) const {
    auto it = map_to_enum.find(str);
    if (it != map_to_enum.end()) {
      return it->second;
    } else
      throw std::invalid_argument("Type " + str + " not recognized.");
  }
};

}  // namespace Utils

#endif  // UTILS_H